@@ -78,8 +78,11 @@ class Buffer(object):
             self.name = buffer.get('name')
             if 'data' in buffer:
                 self.data = bytearray(buffer['data'])
-            else:
+            elif 'uri' in buffer:
                 self.data = load_uri(buffer['uri'], folder=gltf.folder)
+            else:
+                logger.warning('Buffer was empty')
+                return
             if self.byte_length != buffer['byteLength']:
                 raise ValueError('Expected buffer length: ' + str(buffer['byteLength']) + 'does not match actual: ' +
                                  str(self.byte_length))
