@@ -372,15 +372,16 @@ class GLTF(object):
             bv.write_to_buffer()
             data['bufferViews'].append(bv.render(self))
 
-        data['buffers'].append(buffer.render())
-        if split_to:
-            buffer_filename = os.path.basename(split_to) + '.bin'
-            with open(split_to + '.bin', 'wb') as f:
-                f.write(data['buffers'][0].pop('data'))
-            data['buffers'][0]['uri'] = buffer_filename
-        elif gltf_only:
-            data['buffers'][0]['uri'] = 'buffer.bin'
-            data['buffers'][0].pop('data')
+        if self.buffer_views:
+            data['buffers'].append(buffer.render())
+            if split_to:
+                buffer_filename = os.path.basename(split_to) + '.bin'
+                with open(split_to + '.bin', 'wb') as f:
+                    f.write(data['buffers'][0].pop('data'))
+                data['buffers'][0]['uri'] = buffer_filename
+            elif gltf_only:
+                data['buffers'][0]['uri'] = 'buffer.bin'
+                data['buffers'][0].pop('data')
 
         if binary:
             for buf in data['buffers'][1:]:
@@ -390,13 +391,14 @@ class GLTF(object):
             total_size = 0
 
             binary_chunk = b''
-            if not data['buffers'][0].get('uri'):
-                binary_chunk = bytearray(data['buffers'][0].pop('data', b''))
+            if data['buffers']:
+                if not data['buffers'][0].get('uri'):
+                    binary_chunk = bytearray(data['buffers'][0].pop('data', b''))
 
             json_chunk = bytearray(json.dumps(data, separators=(',', ':')).encode())
             if len(json_chunk) % 4:
                 # pad to 4 bytes with spaces
-                json_chunk.extend(bytes([0x20] * (4 - len(json_chunk) % 4)))
+                json_chunk.extend(bytearray([0x20] * (4 - len(json_chunk) % 4)))
 
             json_header = np.array([
                 len(json_chunk),
@@ -409,7 +411,7 @@ class GLTF(object):
             if binary_chunk:
                 if len(binary_chunk) % 4:
                     # pad to 4 bytes with zeroes
-                    binary_chunk.extend(bytes([0x00] * (4 - len(binary_chunk) % 4)))
+                    binary_chunk.extend(bytearray([0x00] * (4 - len(binary_chunk) % 4)))
                 binary_header = np.array([
                     len(binary_chunk),
                     self.BINARY_CHUNK,
