@@ -34,6 +34,7 @@ class Image(object):
     _data = None
     mime_type = None
     gltf = None
+    extras = None
 
     def __init__(self, image, gltf=None):
         if gltf:
@@ -41,6 +42,7 @@ class Image(object):
 
         if type(image) == dict:
             self.name = image.get('name', '')
+            self.extras = image.get('extras')
             try:
                 if 'bufferView' in image:
                     bv = gltf.buffer_views[image['bufferView']]
@@ -113,6 +115,7 @@ class Image(object):
             mime_type = get_image_mime_type(None, data)
             if not mime_type:
                 img_bytes = BytesIO(data)
+                img_bytes.seek(0)
                 try:
                     im = PImage.open(img_bytes)
                 except OSError:
@@ -175,9 +178,11 @@ class Image(object):
             if self.data.startswith('http'):
                 raise ValueError('URI points to externally hosted image')
             with open(self.path, 'rb') as f:
-                return BytesIO(f.read())
-
-        return BytesIO(self.data)
+                b = BytesIO(f.read())
+        else:
+            b = BytesIO(self.data)
+        b.seek(0)
+        return b
 
     def get_pil_image(self):
         """Return a PIL Image from this Image's data."""
@@ -237,6 +242,8 @@ class Image(object):
         image = {}
         if self.name:
             image['name'] = self.name
+        if self.extras:
+            image['extras'] = self.extras
 
         data = self.data
 
@@ -438,6 +445,7 @@ class Material(BaseGLTFStructure):
     glossiness_factor = None
     diffuse_texture = None
     spec_gloss_texture = None
+    extras = None
 
     class AlphaMode(Enum):
         OPAQUE = 'OPAQUE'
@@ -456,6 +464,7 @@ class Material(BaseGLTFStructure):
                  diffuse_texture=None, spec_gloss_texture=None, alpha_cutoff=None):
         if material:
             self.name = material.get('name')
+            self.extras = material.get('extras')
             if material.get('alphaMode'):
                 self.alpha_mode = self.AlphaMode(material.get('alphaMode'))
             if material.get('alphaCutoff'):
@@ -634,6 +643,8 @@ class Material(BaseGLTFStructure):
 
         if self.name:
             material['name'] = self.name
+        if self.extras:
+            material['extras'] = self.extras
         if self.alpha_mode:
             material['alphaMode'] = self.alpha_mode.value
         if self.alpha_cutoff is not None:
