@@ -334,11 +334,11 @@ class Attributes:
 
     def render(self, gltf):
         attributes = {}
-        if self.positions and self.positions.count:
+        if self.positions is not None and self.positions.count:
             attributes['POSITION'] = gltf.index('accessors', self.positions)
-        if self.normals and self.normals.count:
+        if self.normals is not None and self.normals.count:
             attributes['NORMAL'] = gltf.index('accessors', self.normals)
-        if self.tangents and self.tangents.count:
+        if self.tangents is not None and self.tangents.count:
             attributes['TANGENT'] = gltf.index('accessors', self.tangents)
         for i, texcoords in enumerate(self.texcoords):
             attributes['TEXCOORD_' + str(i)] = gltf.index('accessors', texcoords)
