@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 The `ops` module contains a number of useful operations. These can be used to transform a loaded GLTF (in-place) in
 various ways.
@@ -20,6 +22,7 @@ import math
 import numpy as np
 from PIL import Image as PImage, ImageDraw
 
+from .animations import Animation
 from .buffers import Vec2Array, Vec3Array
 
 logger = logging.getLogger(__name__)
@@ -38,6 +41,18 @@ def merge_animations(model):
     model.animations = [anim]
 
 
+def prepend_merged_animations(model):
+    """
+    Merges all of the animations and inserts that as the first animation. This is useful for usdz conversion.
+    """
+    if not model.animations:
+        return
+    anim = Animation(name='All-In-One')
+    for an in model.animations:
+        anim.channels.extend(an.channels)
+    model.animations.insert(0, anim)
+
+
 def sample_textures_to_materials(gltf, min_x=0.83, min_y=0.95):
     """
     Remove the UVs from a portion of the mapping, and recreate those as single-color materials. This is useful to
@@ -122,6 +137,19 @@ def round_accessors(model, decimal_places=3):
                     tc.data = np.round(tc.data, decimal_places)
 
 
+def normalize(a, axis=-1, order=2):
+    l2 = np.atleast_1d(np.linalg.norm(a, order, axis))
+    l2[l2==0] = 1
+    return a / np.expand_dims(l2, axis)
+
+
+def fix_unit_normals(model):
+    for m in model.meshes:
+        for p in m.primitives:
+            if p.normals:
+                p.normals =normalize(p.normals.data)
+
+
 def reindex_all_primitives(model):
     for m in model.meshes:
         for p in m.primitives:
@@ -324,7 +352,7 @@ def analyze(model):
             if p.mode is None or p.mode.value == 4:
                 mesh_triangle_count += int((p.indices.count if p.indices else p.positions.count) / 3)
             else:
-                print(f'Unsupported primitive mode: {p.mode}')
+                print('Unsupported primitive mode: ' + str(p.mode))
         triangle_count += mesh_triangle_count
         mesh_usage_count = 0
         for n in model.nodes:
@@ -394,26 +422,26 @@ def analyze(model):
             'mesh_vertices': {
                 'name': "Mesh Vertices",
                 'count': vertex_count,
-                'recommended': 30_000,
-                'within_limit': vertex_count <= 30_000
+                'recommended': 30000,
+                'within_limit': vertex_count <= 30000
             },
             'instanced_vertices': {
                 'name': "Instanced Vertices",
                 'count': instanced_vertex_count,
-                'recommended': 30_000,
-                'within_limit': instanced_vertex_count <= 30_000
+                'recommended': 30000,
+                'within_limit': instanced_vertex_count <= 30000
             },
             'triangles': {
                 'name': "Triangles",
                 'count': triangle_count,
-                'recommended': 100_000,
-                'within_limit': triangle_count <= 100_000
+                'recommended': 100000,
+                'within_limit': triangle_count <= 100000
             },
             'rendered_triangles': {
                 'name': "Rendered Triangles",
                 'count': rendered_triangle_count,
-                'recommended': 100_000,
-                'within_limit': rendered_triangle_count <= 100_000
+                'recommended': 100000,
+                'within_limit': rendered_triangle_count <= 100000
             },
             'meshes': {
                 'name': "Meshes",
@@ -877,7 +905,7 @@ def get_texture_efficiency(model):
         total_pixels_used += used
         utilization = used / pixels
         efficiencies.append(utilization)
-        print(f'Texture {i}: {utilization:.0%}')
+        print('Texture {}: {:.0%}'.format(i, utilization))
 
     efficiency = (total_pixels_used / total_pixels) if total_pixels else 1
 
